@@ -71,6 +71,25 @@ class TestPatcher(TestCase):
             contents = f.read()
         self.assertEqual("test", contents)
 
+    def test_nested_invocation(self):
+        with Patcher() as patcher:
+            patcher.fs.create_file("/foo/bar", contents="test")
+            self.assertTrue(patcher.fs.exists("/foo/bar"))
+            with Patcher() as patcher1:
+                self.assertTrue(patcher1.fs.exists("/foo/bar"))
+                patcher1.fs.create_file("/foo/baz", contents="test")
+                self.assertTrue(patcher1.fs.exists("/foo/baz"))
+            self.assertTrue(patcher.fs.exists("/foo/baz"))
+
+    def test_nested_invocation_with_args(self):
+        with Patcher() as patcher:
+            patcher.fs.create_file("/foo/bar", contents="test")
+            with self.assertWarnsRegex(
+                UserWarning, "Nested fake filesystem invocation using custom arguments"
+            ):
+                with Patcher(allow_root_user=False):
+                    pass
+
 
 class TestPatchfsArgumentOrder(TestCase):
     @patchfs
@@ -586,6 +605,9 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         self.resume()
         self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
+        self.pause()
+        real_temp_file.close()
+        self.resume()
 
     def test_pause_resume_fs(self):
         fake_temp_file = tempfile.NamedTemporaryFile()
@@ -607,6 +629,9 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         self.fs.resume()
         self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
+        self.fs.pause()
+        real_temp_file.close()
+        self.fs.resume()
 
     def test_pause_resume_contextmanager(self):
         fake_temp_file = tempfile.NamedTemporaryFile()
@@ -618,6 +643,7 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
             real_temp_file = tempfile.NamedTemporaryFile()
             self.assertFalse(self.fs.exists(real_temp_file.name))
             self.assertTrue(os.path.exists(real_temp_file.name))
+            real_temp_file.close()
         self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
 
@@ -631,6 +657,7 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
             real_temp_file = tempfile.NamedTemporaryFile()
             self.assertFalse(self.fs.exists(real_temp_file.name))
             self.assertTrue(os.path.exists(real_temp_file.name))
+            real_temp_file.close()
         self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
 
@@ -662,7 +689,10 @@ class PauseResumePatcherTest(fake_filesystem_unittest.TestCase):
             p.resume()
             self.assertFalse(os.path.exists(real_temp_file.name))
             self.assertTrue(os.path.exists(fake_temp_file.name))
-        real_temp_file.close()
+            fake_temp_file.close()
+            p.pause()
+            real_temp_file.close()
+            p.resume()
 
     def test_pause_resume_contextmanager(self):
         with Patcher() as p:
@@ -675,9 +705,10 @@ class PauseResumePatcherTest(fake_filesystem_unittest.TestCase):
                 real_temp_file = tempfile.NamedTemporaryFile()
                 self.assertFalse(p.fs.exists(real_temp_file.name))
                 self.assertTrue(os.path.exists(real_temp_file.name))
+                real_temp_file.close()
             self.assertFalse(os.path.exists(real_temp_file.name))
             self.assertTrue(os.path.exists(fake_temp_file.name))
-        real_temp_file.close()
+            fake_temp_file.close()
 
 
 class TestPyfakefsTestCase(unittest.TestCase):
@@ -848,6 +879,13 @@ class AutoPatchOpenCodeTestCase(fake_filesystem_unittest.TestCase):
             self.import_foo()
         assert stdout.getvalue() == "hello\n"
 
+    def test_dynamic_import(self):
+        # regression test for #1121
+        self.fs.create_file("/foo.py")
+        self.fs.create_file("/bar.py", contents="import foo")
+        sys.path.insert(0, "")
+        import foo  # noqa
+
 
 class TestOtherFS(fake_filesystem_unittest.TestCase):
     def setUp(self):
