@@ -31,7 +31,8 @@ from unittest import mock
 from unittest.mock import patch
 
 from pyfakefs import fake_pathlib, fake_filesystem, fake_filesystem_unittest, fake_os
-from pyfakefs.fake_filesystem import OSType
+from pyfakefs.fake_filesystem import OSType, FakeFilesystem
+from pyfakefs.fake_pathlib import FakePathlibModule
 from pyfakefs.helpers import IS_PYPY, is_root
 from pyfakefs.tests.skipped_pathlib import (
     check_exists_pathlib,
@@ -70,6 +71,13 @@ class RealPathlibTestCase(fake_filesystem_unittest.TestCase, RealFsTestMixin):
     def use_real_fs(self):
         return False
 
+    def deprecation_warning_since_313(self):
+        return (
+            contextlib.nullcontext()
+            if sys.version_info < (3, 13)
+            else self.assertWarns(DeprecationWarning)
+        )
+
 
 class FakePathlibInitializationTest(RealPathlibTestCase):
     def test_initialization_type(self):
@@ -216,11 +224,7 @@ class FakePathlibPurePathTest(RealPathlibTestCase):
 
     def test_is_reserved_posix(self):
         self.check_posix_only()
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertFalse(self.path("COM1").is_reserved())
@@ -229,11 +233,7 @@ class FakePathlibPurePathTest(RealPathlibTestCase):
     @unittest.skipIf(not is_windows, "Windows specific behavior")
     def test_is_reserved_windows(self):
         self.check_windows_only()
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertTrue(self.path("COM1").is_reserved())
@@ -309,11 +309,7 @@ class FakePathlibPurePosixPathTest(RealPathlibTestCase):
         self.path = self.pathlib.PurePosixPath
 
     def test_is_reserved(self):
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertFalse(self.path("COM1").is_reserved())
@@ -388,11 +384,7 @@ class FakePathlibPureWindowsPathTest(RealPathlibTestCase):
         self.path = self.pathlib.PureWindowsPath
 
     def test_is_reserved(self):
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertTrue(self.path("COM1").is_reserved())
@@ -996,6 +988,13 @@ class FakePathlibPathFileOperationTest(RealPathlibTestCase):
             sorted(path.glob("*.py")),
         )
 
+    def test_glob_dir(self):
+        # regression test for #1239
+        root_dir = self.path(self.make_path("root"))
+        test_file = self.make_path(root_dir, "foo", "bar.txt")
+        self.create_file(test_file)
+        self.assertEqual([root_dir / "foo"], list(root_dir.glob("foo")))
+
     def test_glob_case_windows(self):
         self.check_windows_only()
         self.create_file(self.make_path("foo", "setup.py"))
@@ -1384,6 +1383,107 @@ class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
         with self.assertRaises(NotImplementedError):
             self.path(path).group()
 
+    @unittest.skipIf(sys.version_info < (3, 14), "copy() is new in Python 3.14")
+    def test_copy_new_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="test")
+        target = source_path.copy(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertTrue(target.exists())
+        self.assertEqual("test", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "copy() is new in Python 3.14")
+    def test_copy_to_existing_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="foo")
+        self.create_file(target_path, contents="bar")
+        target = source_path.copy(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertTrue(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual("foo", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "copy() is new in Python 3.14")
+    def test_copy_directory(self):
+        source_path = self.path(self.make_path("some_dir"))
+        self.create_file(source_path / "foo", contents="foo")
+        self.create_file(source_path / "bar", contents="bar")
+        self.create_dir(source_path / "dir")
+        target_path = self.make_path("new_dir")
+        target = source_path.copy(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertTrue(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertTrue((target / "foo").exists())
+        self.assertEqual("foo", (target / "foo").read_text())
+        self.assertEqual("bar", (target / "bar").read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "copy_into() is new in Python 3.14")
+    def test_copy_into(self):
+        source_dir = self.path(self.make_path("some_dir"))
+        source_path = source_dir / "foo"
+        self.create_file(source_path, contents="foo")
+        target_path = self.path(self.make_path("new_dir"))
+        self.create_dir(target_path)
+        target = source_path.copy_into(target_path)
+        self.assertTrue(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual(str(target_path / "foo"), str(target))
+        self.assertEqual("foo", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move() is new in Python 3.14")
+    def test_move_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="test")
+        target = source_path.move(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual("test", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move() is new in Python 3.14")
+    def test_move_to_existing_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="foo")
+        self.create_file(target_path, contents="bar")
+        target = source_path.move(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual("foo", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move() is new in Python 3.14")
+    def test_move_directory(self):
+        source_path = self.path(self.make_path("some_dir"))
+        self.create_file(source_path / "foo", contents="foo")
+        self.create_file(source_path / "bar", contents="bar")
+        self.create_dir(source_path / "dir")
+        target_path = self.make_path("new_dir")
+        target = source_path.move(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertTrue((target / "foo").exists())
+        self.assertEqual("foo", (target / "foo").read_text())
+        self.assertEqual("bar", (target / "bar").read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move_into() is new in Python 3.14")
+    def test_move_into(self):
+        source_dir = self.path(self.make_path("some_dir"))
+        source_path = source_dir / "foo"
+        self.create_file(source_path, contents="foo")
+        target_path = self.path(self.make_path("new_dir"))
+        self.create_dir(target_path)
+        target = source_path.move_into(target_path)
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual(str(target_path / "foo"), str(target))
+        self.assertEqual("foo", target.read_text())
+
     def test_walk(self):
         """Regression test for #915 - walk results shall be strings."""
         base_dir = self.make_path("foo")
@@ -1646,5 +1746,13 @@ class SkipPathlibTest(fake_filesystem_unittest.TestCase):
         self.assertTrue(check_exists_pathlib())
 
 
+class InstantiatedPathlibTest(unittest.TestCase):
+    def test_instantiated_pathlib(self):
+        fake_fs = FakeFilesystem()
+        fake_pathlib_module = FakePathlibModule(fake_fs)
+        top_level_dirs = list(fake_pathlib_module.Path("/").iterdir())
+        self.assertEqual(0, len(top_level_dirs))
+
+
 if __name__ == "__main__":
     unittest.main(verbosity=2)
