@@ -14,16 +14,16 @@
 over modules. The code is modeled after code in xmlbuilder.py in Python 3.6.
 See issue #542.
 """
+
 import warnings
 
 
 class DeprecatedProperty:
-
     def __get__(self, instance, cls):
-        warnings.warn("async is deprecated", DeprecationWarning)
-        warnings.warn("async will be replaced", FutureWarning)
+        warnings.warn("async is deprecated", DeprecationWarning, stacklevel=2)
+        warnings.warn("async will be replaced", FutureWarning, stacklevel=2)
         return instance
 
 
 class DeprecationTest:
-    locals()['async'] = DeprecatedProperty()
+    locals()["async"] = DeprecatedProperty()
